@@ -1,6 +1,6 @@
 import muon.static
 import sys, os
-from SimpleHTTPServer import test
+import SimpleHTTPServer, SocketServer
 from ConfigParser import ConfigParser
 from subprocess import call
 
@@ -14,7 +14,11 @@ def serve():
 	generate()
 	os.chdir(muon.static.SITEDIR)
 	try:
-		test()
+		port = 8000
+		Handler = SimpleHTTPServer.SimpleHTTPRequestHandler
+		httpd = SocketServer.TCPServer(("", port), Handler)
+		print('Serving at http://127.0.0.1:%d' % port)
+		httpd.serve_forever()
 	except KeyboardInterrupt:
 		print('Shutting down ...')
 		sys.exit(0)
